@@ -66,13 +66,7 @@ plot_comparisons <- function(model,
 
     # order of the first few paragraphs is important
     scall <- rlang::enquo(newdata)
-    if (!is.null(condition) && !is.null(newdata)) {
-        insight::format_error("The `condition` and `newdata` arguments cannot be used simultaneously.")
-    }
     newdata <- sanitize_newdata_call(scall, newdata, model)
-    if (!is.null(newdata) && is.null(by)) {
-        insight::format_error("The `newdata` argument requires a `by` argument.")
-    }
     if (!is.null(wts) && is.null(by)) {
         insight::format_error("The `wts` argument requires a `by` argument.")
     }
@@ -89,9 +83,18 @@ plot_comparisons <- function(model,
         checkmate::check_list(variables, names = "unique"),
         .var.name = "variables")
 
+    modeldata <- get_modeldata(
+        model,
+        additional_variables = c(names(condition), by),
+        wts = wts)
+
+    # mlr3 and tidymodels
+    if (is.null(modeldata) || nrow(modeldata) == 0) {
+        modeldata <- newdata
+    }
+
     # conditional
     if (!is.null(condition)) {
-        modeldata <- get_modeldata(model, additional_variables = names(condition), wts = wts)
         condition <- sanitize_condition(model, condition, variables, modeldata = modeldata)
         v_x <- condition$condition1
         v_color <- condition$condition2
@@ -114,7 +117,6 @@ plot_comparisons <- function(model,
 
     # marginal
     if (!is.null(by)) {
-        modeldata <- get_modeldata(model, additional_variables = by, wts = wts)
         newdata <- sanitize_newdata(
             model = model,
             newdata = newdata,
